Documentation
¶
Index ¶
- Constants
- type AddonConfig
- type AdminSecretsConfig
- type AdminSecretsFlags
- type AdminSecretsService
- func (s *AdminSecretsService) AddAdminSecretsValues(cmd *cobra.Command)
- func (s *AdminSecretsService) ChartMuseumAuth() BasicAuth
- func (s *AdminSecretsService) GrafanaAuth() BasicAuth
- func (s *AdminSecretsService) IngressAuth() BasicAuth
- func (s *AdminSecretsService) JenkinsAuth() BasicAuth
- func (s *AdminSecretsService) NewAdminSecretsConfig() error
- func (s *AdminSecretsService) NewAdminSecretsConfigFromSecret(decryptedSecretsFile string) error
- func (s *AdminSecretsService) NewMavenSettingsXML() error
- func (s *AdminSecretsService) NexusAuth() BasicAuth
- type BasicAuth
- type BranchBuild
- type Build
- type ChartMuseum
- type ChartMuseumEnv
- type ChartMuseumSecret
- type ChatConfig
- type ControllerBuildConfig
- type ExposeController
- type ExposeControllerConfig
- type Grafana
- type GrafanaSecret
- type HelmValuesConfig
- type HelmValuesConfigService
- type Image
- type IssueTrackerConfig
- type Jenkins
- type JenkinsAdminSecret
- type JenkinsGiteaServersValuesConfig
- type JenkinsGithubServersValuesConfig
- type JenkinsPipelineSecretsValuesConfig
- type JenkinsServersGlobalConfig
- type JenkinsServersValuesConfig
- type JenkinsValuesConfig
- type KanikoSecret
- type Nexus
- type PipelineSecrets
- type Preview
- type PreviewEnvironmentConfig
- type PreviewValuesConfig
- type ProjectConfig
- type ProwValuesConfig
- type WikiConfig
Constants ¶
const (
// ProjectConfigFileName is the name of the project configuration file
ProjectConfigFileName = "jenkins-x.yml"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddonConfig ¶
type AdminSecretsConfig ¶
type AdminSecretsConfig struct {
IngressBasicAuth string `json:"JXBasicAuth,omitempty"`
ChartMuseum *ChartMuseum `json:"chartmuseum,omitempty"`
Grafana *Grafana `json:"grafana,omitempty"`
Jenkins *Jenkins `json:"jenkins,omitempty"`
Nexus *Nexus `json:"nexus,omitempty"`
PipelineSecrets *PipelineSecrets `json:"PipelineSecrets,omitempty"`
KanikoSecret *KanikoSecret `json:"KanikoSecret,omitempty"`
}
type AdminSecretsFlags ¶
type AdminSecretsService ¶
type AdminSecretsService struct {
FileName string
Secrets AdminSecretsConfig
Flags AdminSecretsFlags
// contains filtered or unexported fields
}
func (*AdminSecretsService) AddAdminSecretsValues ¶
func (s *AdminSecretsService) AddAdminSecretsValues(cmd *cobra.Command)
func (*AdminSecretsService) ChartMuseumAuth ¶
func (s *AdminSecretsService) ChartMuseumAuth() BasicAuth
ChartMuseumAuth returns the current credentials for ChartMuseum
func (*AdminSecretsService) GrafanaAuth ¶
func (s *AdminSecretsService) GrafanaAuth() BasicAuth
GrafanaAuth returns the current credentials for Grafana
func (*AdminSecretsService) IngressAuth ¶
func (s *AdminSecretsService) IngressAuth() BasicAuth
IngressAuth returns the current basic auth credentials for Ingress
func (*AdminSecretsService) JenkinsAuth ¶
func (s *AdminSecretsService) JenkinsAuth() BasicAuth
JenkinsAuth returns the current basic auth credentials for Jenkins
func (*AdminSecretsService) NewAdminSecretsConfig ¶
func (s *AdminSecretsService) NewAdminSecretsConfig() error
func (*AdminSecretsService) NewAdminSecretsConfigFromSecret ¶
func (s *AdminSecretsService) NewAdminSecretsConfigFromSecret(decryptedSecretsFile string) error
func (*AdminSecretsService) NewMavenSettingsXML ¶
func (s *AdminSecretsService) NewMavenSettingsXML() error
NewMavenSettingsXML generates the maven settings
func (*AdminSecretsService) NexusAuth ¶
func (s *AdminSecretsService) NexusAuth() BasicAuth
NexusAuth returns the current credentials for Nexus
type BasicAuth ¶
type BasicAuth struct {
// Username stores the basic authentication user name
Username string `json:"username"`
// Password stores the basic authentication password
Password string `json:"password"`
}
BasicAuth keeps the credentials for basic authentication
type BranchBuild ¶
type BranchBuild struct {
Build Build `yaml:"build,omitempty"`
// which kind of pipeline - like release, pullRequest, feature
Kind string `yaml:"kind,omitempty"`
// display name
Name string `yaml:"name,omitempty"`
// List of sources to populate environment variables in all the steps if there is not already
// an environment variable defined on that step
EnvFrom []corev1.EnvFromSource `yaml:"envFrom,omitempty"`
// List of environment variables to add to each step if there is not already a environemnt variable of that name
Env []corev1.EnvVar `yaml:"env,omitempty"`
ExcludePodTemplateEnv bool `yaml:"excludePodTemplateEnv,omitempty"`
ExcludePodTemplateVolumes bool `yaml:"excludePodTemplateVolumes,omitempty"`
}
type Build ¶
type Build struct {
// Steps are the steps of the build; each step is run sequentially with the
// source mounted into /workspace.
Steps []corev1.Container `yaml:"steps,omitempty"`
// Volumes is a collection of volumes that are available to mount into the
// steps of the build.
Volumes []corev1.Volume `yaml:"volumes,omitempty"`
// The name of the service account as which to run this build.
ServiceAccountName string `yaml:"serviceAccountName,omitempty"`
// NodeSelector is a selector which must be true for the pod to fit on a node.
// Selector which must match a node's labels for the pod to be scheduled on that node.
// More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/
// +optional
NodeSelector map[string]string `yaml:"nodeSelector,omitempty"`
}
type ChartMuseum ¶
type ChartMuseum struct {
ChartMuseumEnv ChartMuseumEnv `json:"env"`
}
type ChartMuseumEnv ¶
type ChartMuseumEnv struct {
ChartMuseumSecret ChartMuseumSecret `json:"secret"`
}
type ChartMuseumSecret ¶
type ChatConfig ¶
type ControllerBuildConfig ¶
type ControllerBuildConfig struct {
Enabled *bool `json:"enabled,omitempty"`
}
ControllerBuildConfig to configure the build controller
type ExposeController ¶
type ExposeController struct {
Config ExposeControllerConfig `json:"config,omitempty"`
Annotations map[string]string `json:"Annotations,omitempty"`
}
type ExposeControllerConfig ¶
type Grafana ¶
type Grafana struct {
GrafanaSecret GrafanaSecret `json:"server"`
}
type GrafanaSecret ¶
type HelmValuesConfig ¶
type HelmValuesConfig struct {
ExposeController *ExposeController `json:"expose,omitempty"`
Jenkins JenkinsValuesConfig `json:"jenkins,omitempty"`
Prow ProwValuesConfig `json:"prow,omitempty"`
PipelineSecrets JenkinsPipelineSecretsValuesConfig `json:"PipelineSecrets,omitempty"`
ControllerBuild ControllerBuildConfig `json:"controllerbuild,omitempty"`
}
func (*HelmValuesConfig) AddExposeControllerValues ¶
func (c *HelmValuesConfig) AddExposeControllerValues(cmd *cobra.Command, ignoreDomain bool)
func (HelmValuesConfig) String ¶
func (c HelmValuesConfig) String() (string, error)
type HelmValuesConfigService ¶
type HelmValuesConfigService struct {
FileName string
Config HelmValuesConfig
}
type IssueTrackerConfig ¶
type Jenkins ¶
type Jenkins struct {
JenkinsSecret JenkinsAdminSecret `json:"Master"`
}
type JenkinsAdminSecret ¶
type JenkinsAdminSecret struct {
Password string `json:"AdminPassword"`
}
type JenkinsPipelineSecretsValuesConfig ¶
type JenkinsPipelineSecretsValuesConfig struct {
DockerConfig string `json:"DockerConfig,flow,omitempty"`
}
type JenkinsServersValuesConfig ¶
type JenkinsServersValuesConfig struct {
Gitea []JenkinsGiteaServersValuesConfig `json:"Gitea,omitempty"`
GHE []JenkinsGithubServersValuesConfig `json:"GHE,omitempty"`
Global JenkinsServersGlobalConfig `json:"Global,omitempty"`
}
func (*JenkinsServersValuesConfig) GetOrCreateFirstGitea ¶
func (c *JenkinsServersValuesConfig) GetOrCreateFirstGitea() *JenkinsGiteaServersValuesConfig
GetOrCreateFirstGitea returns the first gitea server creating one if required
type JenkinsValuesConfig ¶
type JenkinsValuesConfig struct {
Servers JenkinsServersValuesConfig `json:"Servers,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
}
type KanikoSecret ¶ added in v1.3.840
type KanikoSecret struct {
Data string `json:"Data,omitempty"`
}
KanikoSecret store the kaniko service account
type Nexus ¶
type Nexus struct {
DefaultAdminPassword string `json:"defaultAdminPassword,omitempty"`
}
type PipelineSecrets ¶
type PipelineSecrets struct {
MavenSettingsXML string `json:"MavenSettingsXML,omitempty"`
}
type PreviewValuesConfig ¶
type PreviewValuesConfig struct {
ExposeController *ExposeController `json:"expose,omitempty"`
Preview *Preview `json:"preview,omitempty"`
}
func (PreviewValuesConfig) String ¶
func (c PreviewValuesConfig) String() (string, error)
type ProjectConfig ¶
type ProjectConfig struct {
// List of global environment variables to add to each branch build and each step
Env []corev1.EnvVar `yaml:"env,omitempty"`
Builds []*BranchBuild `yaml:"builds,omitempty"`
PreviewEnvironments *PreviewEnvironmentConfig `yaml:"previewEnvironments,omitempty"`
IssueTracker *IssueTrackerConfig `yaml:"issueTracker,omitempty"`
Chat *ChatConfig `yaml:"chat,omitempty"`
Wiki *WikiConfig `yaml:"wiki,omitempty"`
Addons []*AddonConfig `yaml:"addons,omitempty"`
BuildPack string `yaml:"buildPack,omitempty"`
BuildPackGitURL string `yaml:"buildPackGitURL,omitempty"`
BuildPackGitURef string `yaml:"buildPackGitRef,omitempty"`
Workflow string `yaml:"workflow,omitempty"`
PipelineConfig *jenkinsfile.PipelineConfig `yaml:"pipelineConfig,omitempty"`
}
func LoadProjectConfig ¶
func LoadProjectConfig(projectDir string) (*ProjectConfig, string, error)
LoadProjectConfig loads the project configuration if there is a project configuration file
func LoadProjectConfigFile ¶ added in v1.3.886
func LoadProjectConfigFile(fileName string) (*ProjectConfig, error)
LoadProjectConfigFile loads a specific project YAML configuration file
func (*ProjectConfig) IsEmpty ¶
func (c *ProjectConfig) IsEmpty() bool
IsEmpty returns true if this configuration is empty
func (*ProjectConfig) SaveConfig ¶
func (c *ProjectConfig) SaveConfig(fileName string) error
SaveConfig saves the configuration file to the given project directory