Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OptionsInterface ¶
type OptionsInterface interface {
KubeClientAndNamespace() (kubernetes.Interface, string, error)
VaultOperatorClient() (versioned.Interface, error)
GetIn() terminal.FileReader
GetOut() terminal.FileWriter
GetErr() io.Writer
}
OptionsInterface is an interface to allow passing around of a CommonOptions object without dependencies on the whole of the cmd package
Click to show internal directories.
Click to hide internal directories.