Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReturnUserNameIfPicked ¶
ReturnUserNameIfPicked checks to see if PickOrganisation returned "" this will happen if you picked the username as organization which is valid in this scenario and allows code further down to select the appropriate API to call (user or org based)
Types ¶
type UpgradeIngressOptions ¶
type UpgradeIngressOptions struct {
*opts.CommonOptions
SkipCertManager bool
Cluster bool
Force bool
Namespaces []string
Version string
TargetNamespaces []string
Services []string
SkipResourcesUpdate bool
WaitForCerts bool
ConfigNamespace string
IngressConfig kube.IngressConfig
}
UpgradeIngressOptions the options for the create spring command
func (*UpgradeIngressOptions) AnnotateExposedServicesWithCertManager ¶
func (o *UpgradeIngressOptions) AnnotateExposedServicesWithCertManager(svcs ...string) ([]*v1.Service, error)
AnnotateExposedServicesWithCertManager annotates exposed services with cert manager
func (*UpgradeIngressOptions) CleanServiceAnnotations ¶
func (o *UpgradeIngressOptions) CleanServiceAnnotations(svcs ...string) error
CleanServiceAnnotations cleans service annotations
func (*UpgradeIngressOptions) Run ¶
func (o *UpgradeIngressOptions) Run() error
Run implements the command
Click to show internal directories.
Click to hide internal directories.