Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdStart ¶
func NewCmdStart(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdStart creates a command object for the generic "get" action, which retrieves one or more resources from a server.
func NewCmdStartPipeline ¶
func NewCmdStartPipeline(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdStartPipeline creates the command
func NewCmdStartProtection ¶
func NewCmdStartProtection(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdStartProtection creates the command
Types ¶
type StartPipelineOptions ¶
type StartPipelineOptions struct {
*opts.CommonOptions
Output string
Tail bool
Filter string
Branch string
PipelineKind string
JenkinsSelector opts.JenkinsSelectorOptions
Jobs map[string]gojenkins.Job
ProwOptions prow.Options
// meta pipeline options
Context string
CustomLabels []string
CustomEnvs []string
}
StartPipelineOptions contains the command line options
func (*StartPipelineOptions) Run ¶
func (o *StartPipelineOptions) Run() error
Run implements this command
type StartProtectionOptions ¶
type StartProtectionOptions struct {
*opts.CommonOptions
Tail bool
Filter string
Jobs map[string]gojenkins.Job
}
StartProtectionOptions contains the command line options
func (*StartProtectionOptions) Run ¶
func (o *StartProtectionOptions) Run() error
Run implements this command
Click to show internal directories.
Click to hide internal directories.